@@ -1,13 +1,12 @@
 ## no critic: Modules::ProhibitAutomaticExportation
 
-package DD::Dummy;
 package # hide from PAUSE
     DD;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-04'; # DATE
+our $DATE = '2020-06-05'; # DATE
 our $DIST = 'DD-Dummy'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use Exporter qw(import);
 our @EXPORT = qw(dd dd_warn dd_die dmp);
@@ -152,11 +151,11 @@ __END__
 
 =head1 NAME
 
-DD::Dummy - Dump data structure for debugging
+DD - Dump data structure for debugging
 
 =head1 VERSION
 
-This document describes version 0.008 of DD::Dummy (from Perl distribution DD-Dummy), released on 2020-06-04.
+This document describes version 0.009 of DD (from Perl distribution DD-Dummy), released on 2020-06-05.
 
 =head1 SYNOPSIS
 
